# Interesting library

1. Run via command line using default test arguments:
   - run-inspector --url "https://demoqa.com/automation-practice-form"
2. Run project with web_inspector.py file 
- File will be created at the root of the project after first run this command:
  - create-setup --run